supportsDialectApi property
bool
get
supportsDialectApi
True when the loaded native library exports the dialect capability FFIs.
Implementation
bool get supportsDialectApi;
True when the loaded native library exports the dialect capability FFIs.
bool get supportsDialectApi;