OdbcDialectService class
Thin IDialectService over OdbcDriverFeatures.
- Implemented types
Constructors
- OdbcDialectService(OdbcDriverFeatures _features)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsDialectApi → bool
-
True when the loaded native library exports the dialect capability FFIs.
no setteroverride
Methods
-
appendReturningClause(
{required String connectionString, required String sql, required DmlVerb verb, required List< String> columns}) → String? -
Append a RETURNING/OUTPUT clause to
sql.override -
buildUpsertSql(
{required String connectionString, required String table, required List< String> columns, required List<String> conflictColumns, List<String> ? updateColumns}) → String? -
Build an UPSERT statement for the dialect implied by
connectionString.override -
getSessionInitSql(
{required String connectionString, SessionOptions? options}) → List< String> ? -
Post-connect session init statements for the dialect.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited