TelemetryOdbcOperations class

Shared telemetry helpers for ODBC capability decorators.

Constructors

TelemetryOdbcOperations(SimpleTelemetryService _telemetry)
Creates operations bound to the supplied telemetry service.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

inOperation<T>(String name, Future<T> operation()) Future<T>
Wraps an ODBC call in a telemetry span.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrapStream<T>(String operation, Stream<T> factory()) Stream<T>
Wraps a stream-returning ODBC call with open/close telemetry events.

Operators

operator ==(Object other) bool
The equality operator.
inherited