OdbcProfileAsyncDefaults class final
Resolved async worker/backpressure defaults for a usage profile.
Constructors
- OdbcProfileAsyncDefaults({required bool useAsync, required int workerCount, required AsyncBackpressureMode backpressureMode, int? maxPendingRequests, Duration? backpressureTimeout})
-
const
- OdbcProfileAsyncDefaults.fromUsageProfile(OdbcUsageProfile profile)
-
factory
Properties
- backpressureMode → AsyncBackpressureMode
-
final
- backpressureTimeout → Duration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxPendingRequests → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useAsync → bool
-
final
- workerCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited