autoReconnectOnConnectionLost property
When true, the repository may attempt to reconnect and re-execute the operation on connection-lost errors. Default is false.
Implementation
final bool autoReconnectOnConnectionLost;
When true, the repository may attempt to reconnect and re-execute the operation on connection-lost errors. Default is false.
final bool autoReconnectOnConnectionLost;