sqlPointerCacheMaxSize property
Optional max entries for the process-local SQL UTF-8 pointer cache on the native engine constructed for this options set (default 256 when null).
Implementation
final int? sqlPointerCacheMaxSize;
Optional max entries for the process-local SQL UTF-8 pointer cache on the native engine constructed for this options set (default 256 when null).
final int? sqlPointerCacheMaxSize;