ConnectionLost class final

Emitted when _withReconnect notices the underlying ODBC connection has dropped (network error, server restart, idle timeout, etc.). The runtime may follow this with AutoReconnectAttempted events when auto-reconnect is enabled.

Inheritance

Constructors

ConnectionLost({required DateTime timestamp, required String connectionId, required OdbcError reason})
const

Properties

connectionId String
Domain-side connection id that was lost.
final
hashCode int
The hash code for this object.
no setterinherited
reason OdbcError
Typed reason why the connection was considered lost.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
UTC time when the event was emitted by the runtime.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited