ParamValueRefCursorOut class
Placeholder for Oracle SYS_REFCURSOR (and similar) OUT parameters on
the DRT1 wire.
- Inheritance
-
- Object
- ParamValue
- ParamValueRefCursorOut
Constructors
- ParamValueRefCursorOut()
-
Creates a ParamValueRefCursorOut instance.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → List< int> -
Serializes this parameter value to the legacy v0 wire format.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited