DirectedMultiItem class sealed

One item from a multi-result directed response.

Callers should pattern-match on the concrete sub-type:

for (final item in result.additionalResults) {
  switch (item) {
    case DirectedResultItem(:final columns, :final rows, :final rowCount):
      print('rows=$rowCount');
    case DirectedRowCountItem(:final rowCount):
      print('affected=$rowCount');
  }
}
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited