DirectedRowCountItem class final

A row-count item (DML) from a directed multi-result response.

Inheritance

Constructors

DirectedRowCountItem(int rowCount)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
rowCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited