refCursorResults property
When the native RC1\0 trailer is present, each entry is a full result
set materialized from a SYS_REFCURSOR (or similar) OUT parameter.
Implementation
final List<QueryResult> refCursorResults;
When the native RC1\0 trailer is present, each entry is a full result
set materialized from a SYS_REFCURSOR (or similar) OUT parameter.
final List<QueryResult> refCursorResults;