isRowCount property
bool
get
isRowCount
Returns true when this item contains a row count.
Implementation
bool get isRowCount => rowCount != null;
Returns true when this item contains a row count.
bool get isRowCount => rowCount != null;