isRowCount property
bool
get
isRowCount
Returns true if this item is a row count.
Implementation
bool get isRowCount => rowCount != null;
Returns true if this item is a row count.
bool get isRowCount => rowCount != null;