IndexInfo class

Metadata for an index column.

Constructors

IndexInfo({required String indexName, required String tableName, required String columnName, bool isUnique = false, bool isPrimaryKey = false, int? ordinalPosition})
const

Properties

columnName String
final
hashCode int
The hash code for this object.
no setterinherited
indexName String
final
isPrimaryKey bool
final
isUnique bool
final
ordinalPosition int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited