StatementOptions constructor

const StatementOptions({
  1. Duration? timeout,
  2. int? fetchSize,
  3. int? maxBufferSize,
  4. @Deprecated('asyncFetch has no runtime effect and will be removed in a future ' 'major version. Use AsyncNativeOdbcConnection/OdbcService async mode.') bool asyncFetch = false,
})

Implementation

const StatementOptions({
  this.timeout,
  this.fetchSize,
  this.maxBufferSize,
  @Deprecated(
    'asyncFetch has no runtime effect and will be removed in a future '
    'major version. Use AsyncNativeOdbcConnection/OdbcService async mode.',
  )
  this.asyncFetch = false,
});