initialBufferSize property

int? initialBufferSize
final

Initial FFI result buffer seed in bytes for this execution.

When null, the connection initialResultBufferBytes is used, then the package default of 64 KiB.

Implementation

final int? initialBufferSize;