timeout property
Timeout for this specific execution (overrides connection/global).
When null, the connection or global timeout is used.
Implementation
final Duration? timeout;
Timeout for this specific execution (overrides connection/global).
When null, the connection or global timeout is used.
final Duration? timeout;