rowsInsertedBeforeFailure property
Number of rows successfully committed before the first failure.
Implementation
final int rowsInsertedBeforeFailure;
Number of rows successfully committed before the first failure.
final int rowsInsertedBeforeFailure;