TelemetryException class

Base exception for all telemetry errors.

Implemented types
Implementers

Constructors

TelemetryException({required String message, String code = 'UNKNOWN', DateTime? timestamp, dynamic stackTrace})
const
TelemetryException.now({required String message, String code = 'UNKNOWN', dynamic stackTrace})
Creates a TelemetryException with current timestamp.
factory

Properties

code String
Error code for programmatic handling.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → dynamic
Optional stack trace for debugging.
final
timestamp DateTime?
Optional timestamp when error occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited