TelemetryExportException class

Error when telemetry export fails.

Inheritance

Constructors

TelemetryExportException({required String message, String code = 'EXPORT_FAILED', int? attemptNumber, dynamic stackTrace})
const

Properties

attemptNumber int?
final
code String
Error code for programmatic handling.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable description of the error.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → dynamic
Optional stack trace for debugging.
finalinherited
timestamp DateTime?
Optional timestamp when error occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited