scalar<T> method

T? scalar<T>(
  1. String column, {
  2. bool ignoreCase = false,
})

Single scalar from the first row for column, or null when empty or not assignable to T. Alias for firstValue.

Implementation

T? scalar<T>(String column, {bool ignoreCase = false}) =>
    firstValue<T>(column, ignoreCase: ignoreCase);