serviceName property
String
get
serviceName
Service name identifier.
Used in all trace data as the service name.
Implementation
String get serviceName;
Service name identifier.
Used in all trace data as the service name.
String get serviceName;