ITelemetryService class abstract

Interface for telemetry service.

Provides abstraction for telemetry operations to support dependency inversion.

Implementers

Constructors

ITelemetryService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceName String
Service name for all traces.
no setter

Methods

endSpan({required String spanId, Map<String, String> attributes = const {}}) Future<ResultDart<void, TelemetryException>>
Finishes a span by calculating duration.
endTrace({required String traceId, Map<String, String> attributes = const {}}) Future<ResultDart<void, TelemetryException>>
Finishes a trace by calculating duration.
flush() Future<ResultDart<void, TelemetryException>>
Flushes all pending telemetry data.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordEvent({required String name, required TelemetrySeverity severity, required String message, Map<String, dynamic> context = const {}}) Future<ResultDart<void, TelemetryException>>
Records a telemetry event (log entry).
recordGauge({required String name, required double value, Map<String, String> attributes = const {}}) Future<ResultDart<void, TelemetryException>>
Records a gauge metric (current value).
recordMetric({required String name, required String metricType, required double value, String unit = 'count', Map<String, String> attributes = const {}}) Future<ResultDart<void, TelemetryException>>
Records a counter metric.
recordTiming({required String name, required Duration duration, Map<String, String> attributes = const {}}) Future<ResultDart<void, TelemetryException>>
Records a timing metric.
shutdown() Future<ResultDart<void, TelemetryException>>
Shutdown telemetry exporter and release resources.
startSpan({required String parentId, required String spanName, Map<String, String> initialAttributes = const {}}) Future<ResultDart<Span, TelemetryException>>
Creates a child span within an existing trace.
startTrace(String operationName) Future<ResultDart<Trace, TelemetryException>>
Starts a new trace for an ODBC operation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited