OdbcTelemetryAttributes class

Attributes for ODBC-specific telemetry.

Provides typed access to common ODBC telemetry attributes.

Constructors

OdbcTelemetryAttributes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bulkOperationType → const String
Bulk operation type.
cacheMaxSize → const String
Cache max size.
cacheSize → const String
Cache size (current).
cacheStatus → const String
Cache hit/miss status.
connectionId → const String
Connection ID for the operation.
driverName → const String
ODBC driver name.
dsn → const String
DSN or connection string (sanitized).
errorCode → const String
Error code/SQLSTATE from ODBC.
errorMessage → const String
Error message text.
errorType → const String
Error type/category.
fetchSize → const String
Fetch size used.
isolationLevel → const String
Isolation level.
memoryUsage → const String
Memory usage in bytes.
parameterCount → const String
Number of parameters in the query.
poolId → const String
Pool ID.
queryHash → const String
Query hash for cache key.
retryAttempt → const String
Retry attempt number.
retryCount → const String
Retry count.
rowCount → const String
Query result row count.
sql → const String
SQL statement being executed.
statementId → const String
Statement ID for prepared statements.
timeoutMs → const String
Timeout value in milliseconds.
transactionId → const String
Transaction ID.