TelemetryEvent class

Telemetry event for logging significant occurrences.

Constructors

TelemetryEvent({required String name, required TelemetrySeverity severity, required String message, required DateTime timestamp, Map<String, dynamic> context = const {}})
const

Properties

context Map<String, dynamic>
Additional context data.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Message describing the event.
final
name String
Name of the event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity TelemetrySeverity
Severity level of the event.
final
timestamp DateTime
Timestamp when the event occurred.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited