domain/types/param_direction library

Enums

ParamDirection
Declares how a parameter is bound to a statement. Used by DirectedParam for API contracts that will align with future native OUTPUT / INOUT / REF CURSOR work (see doc/notes/TYPE_MAPPING.md).