workerCount property

int workerCount
final

Number of worker isolates used by this async connection.

The default is 1 to preserve the historical behavior. Use values greater than 1 only when concurrent work uses multiple connections or pool checkouts; operations on the same connection are still serialized by the native connection mutex.

Implementation

final int workerCount;