OdbcAuditEvent class

Typed audit event mapped from native JSON payloads.

Constructors

OdbcAuditEvent({required int timestampMs, required String eventType, required int? connectionId, required String? query, required Map<String, String> metadata})
Creates an OdbcAuditEvent.
OdbcAuditEvent.fromJson(Map<String, Object?> json)
Builds an OdbcAuditEvent from a decoded JSON map.
factory

Properties

connectionId int?
final
eventType String
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, String>
final
query String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestampMs int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited