OdbcAuditLogger class

Sync typed wrapper around native audit FFI endpoints.

Uses OdbcNative for transport and exposes parsed model objects for status/events.

Constructors

OdbcAuditLogger(OdbcNative _native)
Creates a typed sync audit logger.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() bool
Clears all in-memory native audit events.
disable() bool
Disables native audit collection.
enable() bool
Enables native audit collection.
getEvents({int limit = 0}) List<OdbcAuditEvent>
Returns parsed audit events.
getStatus() OdbcAuditStatus?
Returns parsed audit status, or null when unavailable/invalid.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited