OdbcAuditStatus class
Typed status payload for native audit subsystem.
Constructors
- OdbcAuditStatus({required bool enabled, required int eventCount})
- Creates an OdbcAuditStatus.
-
OdbcAuditStatus.fromJson(Map<
String, Object?> json) -
Builds an OdbcAuditStatus from a decoded JSON map.
factory
Properties
- enabled → bool
-
final
- eventCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited