StreamBufferFetchResult class

Result of a streaming FFI buffer callback (includes has-more flag).

Constructors

StreamBufferFetchResult({required Uint8List? data, required bool hasMore})
const

Properties

data → Uint8List?
final
hashCode → int
The hash code for this object.
no setterinherited
hasMore → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited