infrastructure/native/bindings/native_byte_view library

Classes

NativeByteView
Internal byte view that retains the native allocation backing a zero-copy FFI result and can derive native pointers for contiguous slices.

Functions

registerNativeByteBacking(Uint8List bytes, Pointer<Uint8> pointer, Finalizable owner) → void
Registers the native allocation that backs bytes.