catalogIndexes method
Queries the database catalog for index information.
The connectionId must be a valid active connection.
The table is the table name to query indexes for.
Returns binary result data on success, null on failure. Result columns: INDEX_NAME, TABLE_NAME, COLUMN_NAME, IS_UNIQUE, IS_PRIMARY, ORDINAL_POSITION
Implementation
Uint8List? catalogIndexes(int connectionId, String table) {
return _withSql(
table,
(tablePtr) => callWithBuffer(
(buf, bufLen, outWritten) => _bindings.odbc_catalog_indexes(
connectionId,
tablePtr,
buf,
bufLen,
outWritten,
),
),
);
}