catalogPrimaryKeys method

Uint8List? catalogPrimaryKeys(
  1. int connectionId,
  2. String table
)

Queries the database catalog for primary key information.

The connectionId must be a valid active connection. The table is the table name to query primary keys for.

Returns binary result data on success, null on failure. Result columns: TABLE_NAME, COLUMN_NAME, ORDINAL_POSITION, CONSTRAINT_NAME

Implementation

Uint8List? catalogPrimaryKeys(int connectionId, String table) {
  return _withSql(
    table,
    (tablePtr) => callWithBuffer(
      (buf, bufLen, outWritten) => _bindings.odbc_catalog_primary_keys(
        connectionId,
        tablePtr,
        buf,
        bufLen,
        outWritten,
      ),
    ),
  );
}