supportsAuditApi property
bool
get
supportsAuditApi
True when the loaded native library exposes the audit FFI API.
Implementation
bool get supportsAuditApi => _bindings.supportsAuditApi;
True when the loaded native library exposes the audit FFI API.
bool get supportsAuditApi => _bindings.supportsAuditApi;