OpenTelemetryFFI class

OpenTelemetry FFI wrapper backed by the native ODBC engine library.

For backward compatibility with previous stub behavior:

  • Success is returned as 1
  • Failure is returned as 0/non-zero native code

Constructors

OpenTelemetryFFI()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exportEvent(String eventJson) int
exportMetric(String metricJson) int
exportSpan(String spanJson) int
exportTrace(String traceJson) int
Exports a single trace JSON payload.
exportTraceToString(String input) int
Exports trace data to an output buffer (native behavior dependent).
flush() int
getLastErrorMessage() String
initialize([String otlpEndpoint = '']) int
Initializes telemetry exporter.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() int
toString() String
A string representation of this object.
inherited
updateSpan(String spanId, String endTime, String attributesJson) int
updateTrace(String traceId, String endTime, String attributesJson) int

Operators

operator ==(Object other) bool
The equality operator.
inherited