TelemetryNativeClient class abstract

Contract used by telemetry repositories to call native telemetry functions.

Implementers

Constructors

TelemetryNativeClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exportEvent(String eventJson) int
exportMetric(String metricJson) int
exportSpan(String spanJson) int
exportTrace(String traceJson) int
exportTraceToString(String input) int
flush() int
getLastErrorMessage() String
initialize([String otlpEndpoint = '']) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() int
toString() String
A string representation of this object.
inherited
updateSpan(String spanId, String endTime, String attributesJson) int
updateTrace(String traceId, String endTime, String attributesJson) int

Operators

operator ==(Object other) bool
The equality operator.
inherited