resetStats method
void
resetStats()
Resets the diagnostic counters without touching the cached entries.
Implementation
void resetStats() {
_hits = 0;
_misses = 0;
_evictions = 0;
}
Resets the diagnostic counters without touching the cached entries.
void resetStats() {
_hits = 0;
_misses = 0;
_evictions = 0;
}