TestOdbcBindingsCapabilities class

Capability flags forced for TestOdbcBindings getters.

Null capability fields fall back to the loaded library.

Annotations
  • @visibleForTesting

Constructors

TestOdbcBindingsCapabilities({bool? supportsAuditApi, bool? supportsDriverCapabilitiesApi, bool? supportsAsyncExecuteApi, bool? supportsAsyncExecuteParamsApi, bool? supportsAsyncStreamApi, bool? supportsTransactionAccessMode, bool? supportsTransactionLockTimeout, bool? supportsXa, bool? supportsExecQueryMultiParams, bool? supportsPoolCreateWithOptions, bool? hasConnectWithTimeoutSymbol})
const

Properties

hasConnectWithTimeoutSymbol bool?
When false, connect-with-timeout uses the v1 connect fallback path.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsAsyncExecuteApi bool?
final
supportsAsyncExecuteParamsApi bool?
final
supportsAsyncStreamApi bool?
final
supportsAuditApi bool?
final
supportsDriverCapabilitiesApi bool?
final
supportsExecQueryMultiParams bool?
final
supportsPoolCreateWithOptions bool?
final
supportsTransactionAccessMode bool?
final
supportsTransactionLockTimeout bool?
final
supportsXa bool?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited