OdbcDriverFeatures class

Typed wrapper for the v3.0 capability FFIs.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsApi bool
True when the loaded native library exposes the v3.0 capability FFIs.
no setter

Methods

appendReturningClause({required String connectionString, required String sql, required DmlVerb verb, required List<String> columns}) String?
Append a RETURNING/OUTPUT clause to sql, using the dialect implied by connectionString.
buildUpsertSql({required String connectionString, required String table, required List<String> columns, required List<String> conflictColumns, List<String>? updateColumns}) String?
Build an UPSERT statement for the dialect implied by connectionString.
getSessionInitSql({required String connectionString, SessionOptions? options}) List<String>?
Returns the post-connect SQL statements for the dialect implied by connectionString, customised by options.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited