supportsApi property
bool
get
supportsApi
True when the loaded native library exposes the v3.0 capability FFIs.
Implementation
bool get supportsApi => _backend.supportsApi;
True when the loaded native library exposes the v3.0 capability FFIs.
bool get supportsApi => _backend.supportsApi;