BulkInsertParallelRequest class

Parallel bulk insert through pool.

Inheritance

Constructors

BulkInsertParallelRequest(int requestId, int poolId, String table, List<String> columns, Uint8List dataBuffer, int parallelism)
const

Properties

columns List<String>
final
dataBuffer Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
parallelism int
final
poolId int
final
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited