CacheMetricsResponse class

Response for cache metrics (sendable record).

Inheritance

Constructors

CacheMetricsResponse(int requestId, {int cacheSize = 0, int cacheMaxSize = 0, int cacheHits = 0, int cacheMisses = 0, int totalPrepares = 0, int totalExecutions = 0, int memoryUsageBytes = 0, double avgExecutionsPerStmt = 0.0, String? error})
const

Properties

avgExecutionsPerStmt double
final
cacheHits int
final
cacheMaxSize int
final
cacheMisses int
final
cacheSize int
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
memoryUsageBytes int
final
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalExecutions int
final
totalPrepares int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited