CatalogIndexesRequest class

Catalog indexes.

Inheritance

Constructors

CatalogIndexesRequest(int requestId, int connectionId, String table, {int? initialBufferBytes, int? maxBufferBytes})
const

Properties

connectionId int
final
hashCode int
The hash code for this object.
no setterinherited
initialBufferBytes int?
final
maxBufferBytes int?
final
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String
final
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited