ExecuteAsyncStartParamsRequest class

Start non-blocking async execution with serialized parameters.

Inheritance

Constructors

ExecuteAsyncStartParamsRequest(int requestId, int connectionId, String sql, Uint8List serializedParams, {int resultEncodingWire = 0})
ExecuteAsyncStartParamsRequest.withSerializedParams(int requestId, int connectionId, String sql, Uint8List serializedParams, {int resultEncodingWire = 0})
factory

Properties

connectionId int
final
hashCode int
The hash code for this object.
no setterinherited
requestId int
finalinherited
resultEncodingWire int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializedParams Uint8List
no setter
sql String
final
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited