ExecutePreparedRequest class
Execute prepared statement. Params sent as serialized Uint8List.
- Inheritance
-
- Object
- WorkerRequest
- ExecutePreparedRequest
Constructors
- ExecutePreparedRequest(int requestId, int stmtId, Uint8List serializedParams, {int timeoutOverrideMs = 0, int fetchSize = 1000, int? maxResultBufferBytes})
- ExecutePreparedRequest.withSerializedParams(int requestId, int stmtId, Uint8List serializedParams, {int timeoutOverrideMs = 0, int fetchSize = 1000, int? maxResultBufferBytes})
-
factory
Properties
- fetchSize → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxResultBufferBytes → int?
-
final
- requestId → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializedParams → Uint8List
-
no setter
- stmtId → int
-
final
- timeoutOverrideMs → int
-
final
- type → RequestType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited