ExecuteQueryMultiParamsRequest class
Execute parameterised multi-result query (M5 in v3.2.0).
- Inheritance
-
- Object
- WorkerRequest
- ExecuteQueryMultiParamsRequest
Constructors
- ExecuteQueryMultiParamsRequest(int requestId, int connectionId, String sql, Uint8List serializedParams, {int? maxResultBufferBytes, int? initialResultBufferBytes})
- ExecuteQueryMultiParamsRequest.withSerializedParams(int requestId, int connectionId, String sql, Uint8List serializedParams, {int? maxResultBufferBytes, int? initialResultBufferBytes})
-
factory
Properties
- connectionId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialResultBufferBytes → int?
-
final
- maxResultBufferBytes → int?
-
final
- requestId → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializedParams → Uint8List
-
no setter
- sql → String
-
final
- type → RequestType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited