ExecuteQueryParamsRequest class
Execute parameterized query. Params sent as serialized Uint8List.
- Inheritance
-
- Object
- WorkerRequest
- ExecuteQueryParamsRequest
Constructors
- ExecuteQueryParamsRequest(int requestId, int connectionId, String sql, Uint8List serializedParams, {int? maxResultBufferBytes, ResultEncoding resultEncoding = ResultEncoding.rowMajor})
-
const
Properties
- connectionId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxResultBufferBytes → int?
-
final
- requestId → int
-
finalinherited
- resultEncoding → ResultEncoding
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializedParams → Uint8List
-
final
- sql → String
-
final
- type → RequestType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited