MetadataCacheEnableRequest class

Enable/reconfigure metadata cache.

Inheritance

Constructors

MetadataCacheEnableRequest(int requestId, {required int maxEntries, required int ttlSeconds})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxEntries int
final
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttlSeconds int
final
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited