PoolCreateRequest class

Create connection pool.

Inheritance

Constructors

PoolCreateRequest(int requestId, String connectionString, int maxSize, {String? optionsJson})
const

Properties

connectionString String
final
hashCode int
The hash code for this object.
no setterinherited
maxSize int
final
optionsJson String?
final
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited