PoolSetSizeRequest class

Resize pool.

Inheritance

Constructors

PoolSetSizeRequest(int requestId, int poolId, int newMaxSize)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
newMaxSize int
final
poolId int
final
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited