StreamMultiStartAsyncRequest class

Start async streaming multi-result batch (M8 in v3.3.0).

Inheritance

Constructors

StreamMultiStartAsyncRequest(int requestId, int connectionId, String sql, {int chunkSize = 64 * 1024})
const

Properties

chunkSize int
final
connectionId int
final
hashCode int
The hash code for this object.
no setterinherited
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sql String
final
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited