StreamPollFetchRequest class
Poll async stream and, when ready, fetch the next chunk in one isolate hop.
- Inheritance
-
- Object
- WorkerRequest
- StreamPollFetchRequest
Constructors
- StreamPollFetchRequest(int requestId, int streamId, {int? bufferSize})
-
const
Properties
- bufferSize → int?
-
Optional FFI output buffer seed (typically stream
chunkSize).final - hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamId → int
-
final
- type → RequestType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited