StreamPollFetchResponse class
Combined poll (+ optional fetch) response for StreamPollFetchRequest.
- Inheritance
-
- Object
- WorkerResponse
- StreamPollFetchResponse
Constructors
- StreamPollFetchResponse(int requestId, {required int status, bool success = true, Uint8List? data, TransferableTypedData? transferableData, bool hasMore = false, String? error})
Properties
- data → Uint8List?
-
no setter
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
final
- requestId → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
Native async poll status (
pending/ready/done/ error codes).final - success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited