XaRecoverResponse class

Response for XaRecoverRequest.

Inheritance

Constructors

XaRecoverResponse(int requestId, {List<XaRecoverEntry> entries = const [], String? error})
const

Properties

entries List<XaRecoverEntry>
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited