XaStartRequest class

Start an XA branch on connectionId.

Inheritance

Constructors

XaStartRequest(int requestId, int connectionId, {required int formatId, required Uint8List gtrid, required Uint8List bqual})
const

Properties

bqual Uint8List
final
connectionId int
final
formatId int
final
gtrid Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
requestId int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type RequestType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited