WorkerFailureSnapshot class

Sendable diagnostic captured on the worker at the failing call.

Constructors

WorkerFailureSnapshot({required String message, required String operation, required int requestId, int? connectionId, String? sqlState, int? nativeCode, OdbcErrorCode code = OdbcErrorCode.query, String? cause, String? stackTrace, String? secondary, bool outcomeUnknown = false, List<WorkerFailureSnapshot> secondaryErrors = const [], int? rowsInsertedBeforeFailure, int? failedChunks, String? bulkDetail, WorkerErrorKind? kind, NativeExecutionStage? executionStage})
const
WorkerFailureSnapshot.fromError(OdbcError error, {required int requestId})
factory

Properties

bulkDetail → String?
final
cause → String?
final
code → OdbcErrorCode
final
connectionId → int?
final
executionStage → NativeExecutionStage?
final
failedChunks → int?
final
hashCode → int
The hash code for this object.
no setterinherited
kind → WorkerErrorKind?
final
message → String
final
nativeCode → int?
final
operation → String
final
outcomeUnknown → bool
final
requestId → int
final
rowsInsertedBeforeFailure → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondary → String?
final
secondaryErrors → List<WorkerFailureSnapshot>
final
sqlState → String?
final
stackTrace → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toError(int workerId) → OdbcError
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

kindOf(OdbcError error) → WorkerErrorKind