supportsAsyncExecuteApi property
Whether the loaded native library supports async execute FFI endpoints.
Implementation
bool get supportsAsyncExecuteApi => _native.supportsAsyncExecuteApi;
Whether the loaded native library supports async execute FFI endpoints.
bool get supportsAsyncExecuteApi => _native.supportsAsyncExecuteApi;