supportsAsyncStreamApi property
Whether the loaded native library supports async stream FFI endpoints.
Implementation
bool get supportsAsyncStreamApi => _native.supportsAsyncStreamApi;
Whether the loaded native library supports async stream FFI endpoints.
bool get supportsAsyncStreamApi => _native.supportsAsyncStreamApi;