supportsMetadataCacheApi property
Whether the loaded native library supports metadata cache FFI endpoints.
Implementation
bool get supportsMetadataCacheApi => _native.supportsMetadataCacheApi;
Whether the loaded native library supports metadata cache FFI endpoints.
bool get supportsMetadataCacheApi => _native.supportsMetadataCacheApi;