isAsync property
bool
get
isAsync
Whether this backend dispatches calls to a worker isolate.
Implementation
bool get isAsync;
Whether this backend dispatches calls to a worker isolate.
bool get isAsync;