supportsApi property
bool
get
supportsApi
True when the loaded native library exposes map pool create with options.
Implementation
bool get supportsApi => _native.supportsPoolCreateWithOptions;
True when the loaded native library exposes map pool create with options.
bool get supportsApi => _native.supportsPoolCreateWithOptions;