connectionTimeout property
Maximum time acquire will wait for an available connection.
null falls back to the engine default (30 s).
Implementation
final Duration? connectionTimeout;
Maximum time acquire will wait for an available connection.
null falls back to the engine default (30 s).
final Duration? connectionTimeout;