idleTimeout property
Connections idle for longer than this are closed by the background
reaper. null disables idle eviction.
Implementation
final Duration? idleTimeout;
Connections idle for longer than this are closed by the background
reaper. null disables idle eviction.
final Duration? idleTimeout;