maxLifetime property
A connection is closed when it exceeds this lifetime (checked on return
to the pool). null disables lifetime eviction.
Implementation
final Duration? maxLifetime;
A connection is closed when it exceeds this lifetime (checked on return
to the pool). null disables lifetime eviction.
final Duration? maxLifetime;