BinaryProtocolBufferReader class

Internal buffer reader for parsing binary protocol data.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBytes(int length) → Uint8List
readInt32Le() → int
Reads a little-endian i32 from the current offset without allocating.
readInt64Le() → int
Reads a little-endian i64 from the current offset without allocating.
readString(int length) → String
readUint16() → int
readUint32() → int
readUint8() → int
skip(int length) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited