table method

BulkInsertBuilder table(
  1. String name
)
inherited

Sets the target table name for the bulk insert.

The name is the table name where rows will be inserted. Returns this builder for method chaining.

Implementation

BulkInsertBuilder table(String name) {
  _table = name;
  return _self;
}