BinaryFrameAccumulator class
Incrementally accumulates binary protocol bytes and yields complete frames.
Constructors
Properties
Methods
-
add(
Uint8List chunk) → void -
drainFrames(
) → Iterable< Uint8List> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited