rowCount property
Number of affected rows (for INSERT/UPDATE/DELETE).
Null when this item represents a row count instead.
Implementation
final int? rowCount;
Number of affected rows (for INSERT/UPDATE/DELETE).
Null when this item represents a row count instead.
final int? rowCount;