MultiResultItemResultSet class final

A MultiResultItem carrying a ParsedRowBuffer (cursor-shaped result).

Inheritance

Constructors

MultiResultItemResultSet(ParsedRowBuffer value, {bool isContinuationBatch = false})
Creates a result-set item.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isContinuationBatch bool
Whether this frame continues the previous result-set cursor (tag 2).
final
resultSet ParsedRowBuffer?
Returns the result set if this is a MultiResultItemResultSet.
no setterinherited
rowCount int?
Returns the row count if this is a MultiResultItemRowCount.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ParsedRowBuffer
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited