TelemetryExporter class abstract

Interface for telemetry exporters.

Implementations can send telemetry data to various backends such as OpenTelemetry OTLP, console stdout, files, etc.

Implementers

Constructors

TelemetryExporter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

exportEvent(TelemetryEvent event) Future<ResultDart<void, Exception>>
exportMetric(Metric metric) Future<ResultDart<void, Exception>>
exportSpan(Span span) Future<ResultDart<void, Exception>>
exportTrace(Trace trace) Future<ResultDart<void, Exception>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited