CatalogQuery class

Wrapper for database catalog queries.

Provides convenient methods to query database metadata including tables, columns, and data type information.

Example:

final catalog = CatalogQuery(backend, connectionId);
final tables = catalog.tables(catalog: 'MyDatabase');

Constructors

CatalogQuery(OdbcConnectionBackend _backend, int _connectionId)
Creates a new CatalogQuery instance.

Properties

connectionId → int
The connection ID used for catalog queries.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

columns(String table) → ParsedRowBuffer?
Queries the database catalog for column information.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tables({String catalog = '', String schema = ''}) → ParsedRowBuffer?
Queries the database catalog for table information.
toString() → String
A string representation of this object.
inherited
typeInfo() → ParsedRowBuffer?
Queries the database catalog for data type information.

Operators

operator ==(Object other) → bool
The equality operator.
inherited