TransactionCompletionStatus class abstract interface

Optional raw completion status used by the native transaction wrapper. Legacy backends keep using the boolean transaction methods.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

commitTransactionStatus(int txnId) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rollbackTransactionStatus(int txnId) → int
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited