StreamChunkDecoder class

Decodes stream wire chunks into typed columnar or row-major buffers.

Constructors

StreamChunkDecoder(OdbcResultParser _parser)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decodeColumnarFrame(Uint8List frame, {bool lazyStrings = false}) TypedColumnarResult
Decodes a complete protocol message frame for columnar streaming.
decodeExecuteBuffer(Uint8List? buf, {bool lazyStrings = false}) TypedColumnarResult?
Decodes a buffer from a non-stream execute into typed columnar form.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited