StreamErrorMapper class

Maps streaming exceptions to typed repository failures.

Constructors

StreamErrorMapper(OdbcFfiDispatch ffi)
const

Properties

ffi OdbcFfiDispatch
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isStreamingInterruptionException(Exception error) bool
isStreamingProtocolException(Exception error, String normalizedMessage) bool
isStreamingTimeoutException(Exception error, String normalizedMessage) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
streamingColumnarFailureFromException(Exception error) Future<Failure<TypedColumnarResult, OdbcError>>
streamingFailureFromException(Exception error) Future<Failure<QueryResult, OdbcError>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited