Transaction-shaped operations subset of IOdbcService.
Local 2PC primitives without the rest of the surface (queries, pool,
admin). XA / 2PC operations remain on the aggregate IOdbcService
because they expose helper types (XaTransactionHandle) that bring
in heavier dependencies.
- Implementers
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginTransaction(
String connectionId, {IsolationLevel? isolationLevel, SavepointDialect? savepointDialect, TransactionAccessMode? accessMode, Duration? lockTimeout}) → Future< Result< int> > -
beginTransactionFor(
Connection conn, {IsolationLevel? isolationLevel, SavepointDialect? savepointDialect, TransactionAccessMode? accessMode, Duration? lockTimeout}) → Future< Result< int> > -
Available on ITransactionService, provided by the ITransactionServiceConnectionOverloads extension
beginTransactionoverload that accepts a Connection. -
commitTransaction(
String connectionId, int txnId) → Future< Result< void> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rollbackTransaction(
String connectionId, int txnId) → Future< Result< void> > -
runInTransaction<
T extends Object> (String connectionId, Future< Result< action(int txnId), {IsolationLevel? isolationLevel, SavepointDialect? savepointDialect, TransactionAccessMode? accessMode, Duration? lockTimeout}) → Future<T> >Result< T> > -
Run
actioninside a freshly opened transaction with automatic commit-on-success / rollback-on-failure semantics. -
runInTransactionFor<
T extends Object> (Connection conn, Future< Result< action(int txnId), {IsolationLevel? isolationLevel, SavepointDialect? savepointDialect, TransactionAccessMode? accessMode, Duration? lockTimeout}) → Future<T> >Result< T> > -
Available on ITransactionService, provided by the ITransactionServiceConnectionOverloads extension
runInTransactionoverload that accepts a Connection. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited