OdbcPoolService class

Pool capability delegate for the ODBC service façade.

Constructors

OdbcPoolService(IPoolRepository _repository)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
poolClose(int poolId) Future<Result<void>>
poolCreate(String connectionString, int maxSize, {PoolOptions? options, ConnectionOptions? connectionOptions}) Future<Result<int>>
poolGetConnection(int poolId, {ConnectionOptions? options}) Future<Result<Connection>>
poolGetState(int poolId) Future<Result<PoolState>>
poolGetStateDetailed(int poolId) Future<Result<Map<String, Object?>>>
poolHealthCheck(int poolId) Future<Result<bool>>
poolReleaseConnection(String connectionId) Future<Result<void>>
poolSetSize(int poolId, int newMaxSize) Future<Result<void>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited