OdbcTransactionService class
Transaction / savepoint / XA capability delegate for the ODBC service façade.
Constructors
- OdbcTransactionService(ITransactionRepository _repository)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
beginTransaction(
String connectionId, {IsolationLevel? isolationLevel, SavepointDialect? savepointDialect, TransactionAccessMode? accessMode, Duration? lockTimeout}) → Future< Result< int> > -
commitTransaction(
String connectionId, int txnId) → Future< Result< void> > -
createSavepoint(
String connectionId, int txnId, String name) → Future< Result< void> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
releaseSavepoint(
String connectionId, int txnId, String name) → Future< Result< void> > -
rollbackToSavepoint(
String connectionId, int txnId, String name) → Future< Result< void> > -
rollbackTransaction(
String connectionId, int txnId) → Future< Result< void> > -
runInTransaction<
T extends Object> (String connectionId, Future< Result< action(int txnId), {IsolationLevel? isolationLevel, SavepointDialect? savepointDialect, TransactionAccessMode? accessMode, Duration? lockTimeout}) → Future<T> >Result< T> > -
runInXaTransaction<
T extends Object> (String connectionId, Xid xid, Future< Result< action(XaTransactionHandle xa), {bool onePhase = false}) → Future<T> >Result< T> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited