blockFetchBatchSize property
Preferred ODBC block-fetch row batch for buffered executeQuery* drains.
When null or not positive, the native engine uses
ODBC_FAST_BLOCK_FETCH_BATCH (default 256). A positive value is sent on
odbc_exec_query_params_fetch / odbc_execute_async_params_fetch when
those symbols are loaded. Prepared statements use
StatementOptions.fetchSize when it is set, and this field only when
that option is null.
Implementation
final int? blockFetchBatchSize;