DriverCapabilities class
Typed driver capabilities parsed from native JSON payload.
Constructors
- DriverCapabilities({required bool supportsPreparedStatements, required bool supportsBatchOperations, required bool supportsStreaming, required int maxRowArraySize, required String driverName, required String driverVersion, required DatabaseType databaseType, required String engineId, required bool supportsNativeBcp})
-
const
Properties
- databaseType → DatabaseType
-
final
- driverName → String
-
final
- driverVersion → String
-
final
- engineId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRowArraySize → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsBatchOperations → bool
-
final
- supportsNativeBcp → bool
-
Whether the native engine was built with
sqlserver-bcpon Windows for this engine. Does not implyODBC_ENABLE_UNSTABLE_NATIVE_BCPis set.final - supportsPreparedStatements → bool
-
final
- supportsStreaming → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited