QueryResultMultiItem class

One item in a multi-result response.

An item is either a resultSet or a rowCount.

Constructors

QueryResultMultiItem.resultSet(QueryResult? resultSet)
Creates a result-set item.
const
QueryResultMultiItem.rowCount(int? rowCount)
Creates a row-count item.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isResultSet bool
Returns true if this item is a result set.
no setter
isRowCount bool
Returns true if this item is a row count.
no setter
resultSet QueryResult?
Result set payload, when this item is a result-set item.
final
rowCount int?
Affected rows payload, when this item is a row-count item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited