StatementOptions class
Options for a single prepared statement execution.
These options apply to a single execution and override any connection-level or global options.
Constructors
- StatementOptions({Duration? timeout, int? fetchSize, int? maxBufferSize, @Deprecated('asyncFetch has no runtime effect and will be removed in a future ' 'major version. Use AsyncNativeOdbcConnection/OdbcService async mode.') bool asyncFetch = false})
-
const
Properties
- asyncFetch → bool
-
Use async fetch when available.
final
- fetchSize → int?
-
Number of rows to fetch per batch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBufferSize → int?
-
Maximum result buffer size in bytes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
Timeout for this specific execution (overrides connection/global).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited