StatementOptions constructor
const
StatementOptions({
- Duration? timeout,
- int? fetchSize,
- int? maxBufferSize,
- @Deprecated('asyncFetch has no runtime effect and will be removed in a future ' 'major version. Use AsyncNativeOdbcConnection/OdbcService async mode.') bool asyncFetch = false,
Implementation
const StatementOptions({
this.timeout,
this.fetchSize,
this.maxBufferSize,
@Deprecated(
'asyncFetch has no runtime effect and will be removed in a future '
'major version. Use AsyncNativeOdbcConnection/OdbcService async mode.',
)
this.asyncFetch = false,
});