asyncFetch property
- @Deprecated('asyncFetch has no runtime effect and will be removed in a future ' 'major version. Use AsyncNativeOdbcConnection/OdbcService async mode.')
final
Use async fetch when available.
Deprecated: this flag has no runtime effect.
Keep using async mode via AsyncNativeOdbcConnection or service
configured with async backend.
Implementation
@Deprecated(
'asyncFetch has no runtime effect and will be removed in a future '
'major version. Use AsyncNativeOdbcConnection/OdbcService async mode.',
)
final bool asyncFetch;