OdbcErrorDetails class
Technical context. Presentation code should use OdbcError.userMessage.
Constructors
-
OdbcErrorDetails({OdbcErrorCode? code, String? operation, Object? cause, StackTrace? stackTrace, String? transactionId, String? connectionId, int? requestId, int? workerId, int? attempt, bool outcomeUnknown = false, List<
OdbcError> secondaryErrors = const []}) -
const
Properties
- attempt → int?
-
final
- cause → Object?
-
final
- code → OdbcErrorCode?
-
final
- connectionId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- operation → String?
-
final
- outcomeUnknown → bool
-
final
- requestId → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secondaryErrors
→ List<
OdbcError> -
final
- stackTrace → StackTrace?
-
final
- transactionId → String?
-
final
- workerId → int?
-
final
Methods
-
copyWith(
{OdbcErrorCode? code, String? operation, Object? cause, StackTrace? stackTrace, String? transactionId, String? connectionId, int? requestId, int? workerId, int? attempt, bool? outcomeUnknown, List< OdbcError> ? secondaryErrors}) → OdbcErrorDetails -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited