domain/types/param_direction library
Enums
- ParamDirection
-
Declares how a parameter is bound to a statement. Used by
DirectedParamfor API contracts that will align with future native OUTPUT /INOUT/REF CURSORwork (seedoc/notes/TYPE_MAPPING.md).