streamFetch method

Future<StreamFetchResponse> streamFetch(
  1. int streamId
)

Fetches the next chunk from an active stream in the worker. Public counterpart of _streamFetch, used by callers that drive the stream lifecycle themselves (e.g. streamQueryMulti). New in v3.3.0.

Implementation

Future<StreamFetchResponse> streamFetch(int streamId) =>
    _streamFetch(streamId);