OdbcBindings class

Constructors

OdbcBindings(DynamicLibrary _dylib)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsAsyncExecuteApi bool
no setter
supportsAsyncStreamApi bool
no setter
supportsAuditApi bool
no setter
supportsDriverCapabilitiesApi bool
no setter
supportsMetadataCacheApi bool
no setter
supportsStructuredErrorForConnection bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
odbc_async_cancel(int requestId) int?
odbc_async_free(int requestId) int?
odbc_async_get_result(int requestId, Pointer<Uint8> outBuf, int bufLen, Pointer<Uint32> outWritten) int?
odbc_async_poll(int requestId, Pointer<Int32> outStatus) int?
odbc_audit_clear() int
odbc_audit_enable(int enabled) int
odbc_audit_get_events(Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten, int limit) int
odbc_audit_get_status(Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_bulk_insert_array(int connId, Pointer<Utf8> table, Pointer<Pointer<Utf8>> columns, int columnCount, Pointer<Uint8> dataBuffer, int bufferLen, int rowCount, Pointer<Uint32> rowsInserted) int
odbc_bulk_insert_parallel(int poolId, Pointer<Utf8> table, Pointer<Pointer<Utf8>> columns, int columnCount, Pointer<Uint8> dataBuffer, int bufferLen, int parallelism, Pointer<Uint32> rowsInserted) int
odbc_cancel(int stmtId) int
odbc_catalog_columns(int connId, Pointer<Utf8> table, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_catalog_foreign_keys(int connId, Pointer<Utf8> table, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_catalog_indexes(int connId, Pointer<Utf8> table, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_catalog_primary_keys(int connId, Pointer<Utf8> table, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_catalog_tables(int connId, Pointer<Utf8> catalog, Pointer<Utf8> schema, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_catalog_type_info(int connId, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_clear_all_statements() int
odbc_clear_statement_cache() int
odbc_close_statement(int stmtId) int
odbc_connect(Pointer<Utf8> connStr) int
odbc_connect_with_timeout(Pointer<Utf8> connStr, int timeoutMs) int
odbc_detect_driver(Pointer<Utf8> connStr, Pointer<Int8> outBuf, int bufferLen) int
odbc_disconnect(int connId) int
odbc_exec_query(int connId, Pointer<Utf8> sql, Pointer<Uint8> outBuf, int bufLen, Pointer<Uint32> outWritten) int
odbc_exec_query_multi(int connId, Pointer<Utf8> sql, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_exec_query_params(int connId, Pointer<Utf8> sql, Pointer<Uint8>? paramsBuffer, int paramsLen, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_execute(int stmtId, Pointer<Uint8>? paramsBuffer, int paramsLen, int timeoutOverrideMs, int fetchSize, Pointer<Uint8> outBuffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_execute_async(int connId, Pointer<Utf8> sql) int?
odbc_get_cache_metrics(Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_get_driver_capabilities(Pointer<Utf8> connStr, Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_get_error(Pointer<Int8> buffer, int bufferLen) int
odbc_get_metrics(Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_get_structured_error(Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_get_structured_error_for_connection(int connId, Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int?
odbc_get_version(Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_init() int
odbc_metadata_cache_clear() int
odbc_metadata_cache_enable(int maxEntries, int ttlSeconds) int
odbc_metadata_cache_stats(Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_pool_close(int poolId) int
odbc_pool_create(Pointer<Utf8> connStr, int maxSize) int
odbc_pool_get_connection(int poolId) int
odbc_pool_get_state(int poolId, Pointer<Uint32> outSize, Pointer<Uint32> outIdle) int
odbc_pool_get_state_json(int poolId, Pointer<Uint8> buffer, int bufferLen, Pointer<Uint32> outWritten) int
odbc_pool_health_check(int poolId) int
odbc_pool_release_connection(int connectionId) int
odbc_pool_set_size(int poolId, int newMaxSize) int
odbc_prepare(int connId, Pointer<Utf8> sql, int timeoutMs) int
odbc_savepoint_create(int txnId, Pointer<Utf8> name) int
odbc_savepoint_release(int txnId, Pointer<Utf8> name) int
odbc_savepoint_rollback(int txnId, Pointer<Utf8> name) int
odbc_set_log_level(int level) int
odbc_stream_cancel(int streamId) int
odbc_stream_close(int streamId) int
odbc_stream_fetch(int streamId, Pointer<Uint8> outBuf, int bufLen, Pointer<Uint32> outWritten, Pointer<Uint8> hasMore) int
odbc_stream_poll_async(int streamId, Pointer<Int32> outStatus) int?
odbc_stream_start(int connId, Pointer<Utf8> sql, int chunkSize) int
odbc_stream_start_async(int connId, Pointer<Utf8> sql, int fetchSize, int chunkSize) int?
odbc_stream_start_batched(int connId, Pointer<Utf8> sql, int fetchSize, int chunkSize) int
odbc_transaction_begin(int connId, int isolationLevel, [int savepointDialect = 0]) int
odbc_transaction_commit(int txnId) int
odbc_transaction_rollback(int txnId) int
odbc_validate_connection_string(Pointer<Utf8> connStr, Pointer<Uint8> errorBuffer, int errorBufferLen) int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited