catalogForeignKeys method
Queries the database catalog for foreign key information.
The connectionId must be a valid active connection.
The table is the table name to query foreign keys for.
Returns binary result data on success, null on failure. Result columns: CONSTRAINT_NAME, FROM_TABLE, FROM_COLUMN, TO_TABLE, TO_COLUMN, UPDATE_RULE, DELETE_RULE
Implementation
Uint8List? catalogForeignKeys(int connectionId, String table) {
return _withSql(
table,
(tablePtr) => callWithBuffer(
(buf, bufLen, outWritten) => _bindings.odbc_catalog_foreign_keys(
connectionId,
tablePtr,
buf,
bufLen,
outWritten,
),
),
);
}