OpenTelemetryFFI class

OpenTelemetry FFI wrapper backed by the native ODBC engine library.

For backward compatibility with previous stub behavior:

  • Success is returned as 1
  • Failure is returned as 0/non-zero native code
Implemented types

Constructors

OpenTelemetryFFI()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

exportEvent(String eventJson) → int
override
exportMetric(String metricJson) → int
override
exportSpan(String spanJson) → int
override
exportTrace(String traceJson) → int
Exports a single trace JSON payload.
override
exportTraceToString(String input) → int
Exports trace data to an output buffer (native behavior dependent).
override
flush() → int
override
getLastErrorMessage() → String
override
initialize([String otlpEndpoint = '']) → int
Initializes telemetry exporter.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() → int
override
toString() → String
A string representation of this object.
inherited
updateSpan(String spanId, String endTime, String attributesJson) → int
override
updateTrace(String traceId, String endTime, String attributesJson) → int
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited