DatabaseEngineIds class
Canonical engine identifier returned by the Rust layer
(engine::core::ENGINE_*). Stable across releases.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bigquery → const String
- db2 → const String
- mariadb → const String
- mongodb → const String
- mysql → const String
- oracle → const String
- postgres → const String
- redshift → const String
- snowflake → const String
- sqlite → const String
- sqlserver → const String
- sybaseAsa → const String
- sybaseAse → const String
- unknown → const String