DbmsInfo class
Live DBMS introspection (NEW in v2.1). Populated by
odbc_get_connection_dbms_info once the connection is open.
Constructors
- DbmsInfo({required String dbmsName, required String engineId, required DatabaseType databaseType, required int maxCatalogNameLen, required int maxSchemaNameLen, required int maxTableNameLen, required int maxColumnNameLen, required String currentCatalog, required DriverCapabilities capabilities})
-
DbmsInfo.fromJson(Map<
String, Object?> json) -
factory
Properties
- capabilities → DriverCapabilities
-
Capabilities derived from the live DBMS name.
final
- currentCatalog → String
-
Currently selected catalog/database (empty if not applicable).
final
- databaseType → DatabaseType
-
Logical database family (preferred over dbmsName for switch/case).
final
- dbmsName → String
-
Server-reported
SQL_DBMS_NAME(e.g."Microsoft SQL Server","PostgreSQL","MariaDB","Adaptive Server Anywhere").final - engineId → String
-
Canonical engine id (one of DatabaseEngineIds).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCatalogNameLen → int
-
final
- maxColumnNameLen → int
-
final
- maxSchemaNameLen → int
-
final
- maxTableNameLen → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited