OdbcDriverCapabilities class
Typed wrapper for native driver capabilities FFI.
Constructors
- OdbcDriverCapabilities(OdbcNative _native)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsApi → bool
-
Whether the loaded native library exposes driver capabilities API.
no setter
Methods
-
getCapabilities(
String connectionString) → DriverCapabilities? -
Returns parsed capabilities from
connectionString, or null when unavailable or invalid. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited