Backend contract used by OdbcDriverFeatures.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsApi → bool
-
no setter
Methods
-
appendReturningClause(
String connectionString, String sql, int verbCode, String columnsCsv) → Uint8List? -
buildUpsertSql(
String connectionString, String table, String payloadJson) → Uint8List? -
getSessionInitSql(
String connectionString, String? optionsJson) → Uint8List? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited