BeginTransactionRequest class
Begin transaction.
- Inheritance
-
- Object
- WorkerRequest
- BeginTransactionRequest
Constructors
Properties
- accessMode → int
-
Wire code from
TransactionAccessMode.code(0=readWrite,1=readOnly). Default isreadWriteso legacy callers keep working unchanged. Sprint 4.1.final - connectionId → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolationLevel → int
-
final
- lockTimeoutMs → int
-
Per-transaction lock timeout in milliseconds.
0= engine default (no override). Default is0so legacy callers keep working unchanged. Sprint 4.2.final - requestId → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savepointDialect → int
-
Wire code from
SavepointDialect.code(0=auto,1=sqlServer,2=sql92). Default isautoso legacy callers keep working.final - type → RequestType
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited