ValidateConnectionStringResponse class
Response for connection string validation.
- Inheritance
-
- Object
- WorkerResponse
- ValidateConnectionStringResponse
Constructors
- ValidateConnectionStringResponse(int requestId, {required bool isValid, String? errorMessage})
-
const
Properties
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool
-
final
- requestId → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited