poolCreate method
Creates a new connection pool.
The connectionString is used to establish connections in the pool.
The maxSize specifies the maximum number of connections in the pool.
Returns a pool ID on success, 0 on failure.
Implementation
int poolCreate(
String connectionString,
int maxSize, {
PoolOptions? options,
}) {
if (options == null || !options.hasAnyOption) {
return _native.poolCreate(connectionString, maxSize);
}
return _native.poolCreateWithOptions(
connectionString,
maxSize,
optionsJson: options.toJson(),
);
}