AsyncBackend class final
Asynchronous backend backed by an AsyncNativeOdbcConnection.
- Inheritance
-
- Object
- OdbcBackend
- AsyncBackend
Constructors
- AsyncBackend(AsyncNativeOdbcConnection connection)
-
const
Properties
- connection → AsyncNativeOdbcConnection
-
The wrapped async ODBC connection.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAsync → bool
-
Whether this backend dispatches calls to a worker isolate.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited