OdbcPoolFactory class

Typed wrapper for the v3.0 pool-creation FFI with options support.

Constructors

OdbcPoolFactory(OdbcNative _native)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsApi → bool
True when the loaded native library exposes map pool create with options.
no setter

Methods

createPool(String connectionString, int maxSize, {PoolOptions? options}) → int
Create a pool. When options is null or has no fields set, falls back to the legacy odbc_pool_create (no options) for maximum compatibility.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited