BinaryProtocolParser class
Parser for binary protocol query results.
Facade over row-major, columnar, and trailer sub-parsers. Use parseColumnarToTyped for columnar wire payloads that should stay column-major; parse / parseWithOutputs remain for row-major ParsedRowBuffer backward compatibility.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isColumnarV2Message(
Uint8List data) → bool -
True when
databegins with a columnar v2 header. -
messageLengthFromHeader(
Uint8List data) → int -
parse(
Uint8List data, {bool lazyStrings = false}) → ParsedRowBuffer -
parseColumnarToTyped(
Uint8List data, {bool lazyStrings = false}) → TypedColumnarResult - Decodes columnar v2 wire bytes directly to TypedColumnarResult.
-
parseColumnarWithOutputs(
Uint8List data, {bool lazyStrings = false}) → ParsedColumnarQueryMessage -
parseWithOutputs(
Uint8List data, {bool lazyStrings = false}) → ParsedQueryMessage
Constants
- headerSize → const int
- headerSizeColumnarV2 → const int
- headerSizeV1 → const int
- magic → const int
- protocolVersionColumnarV2 → const int
- protocolVersionRowMajor → const int