BinaryProtocolBufferReader class

Internal buffer reader for parsing binary protocol data.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBytes(int length) Uint8List
readString(int length) String
readUint16() int
readUint32() int
readUint8() int
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited