DirectedParam class

A parameter with an explicit ParamDirection for API surfaces that prepare the contract for OUTPUT / INOUT (native engine support is still being rolled in — see doc/notes/TYPE_MAPPING.md 3.1).

When direction is ParamDirection.input and type is null, the payload serialises the same as an untyped value.

Constructors

DirectedParam({required Object? value, SqlDataType? type, ParamDirection direction = ParamDirection.input})
const

Properties

direction ParamDirection
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SqlDataType?
final
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited