MultiResultItemResultSet class final
A MultiResultItem carrying a ParsedRowBuffer (cursor-shaped result).
- Inheritance
-
- Object
- MultiResultItem
- MultiResultItemResultSet
Constructors
- MultiResultItemResultSet(ParsedRowBuffer value)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resultSet → ParsedRowBuffer?
-
Backward-compatible accessor: returns the result set if this is a
MultiResultItemResultSet, otherwise
null.no setterinherited - rowCount → int?
-
Backward-compatible accessor: returns the row count if this is a
MultiResultItemRowCount, otherwise
null.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → ParsedRowBuffer
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited