ConsoleExporter class
Exporter that writes telemetry to console for debugging/fallback.
Used when OTLP exporter is unavailable or fails. Provides simple stdout/stderr output for all telemetry data.
- Implemented types
Constructors
- ConsoleExporter({IOSink? output})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
exportEvent(
TelemetryEvent event) → Future< ResultDart< void, Exception> > -
override
-
exportMetric(
Metric metric) → Future< ResultDart< void, Exception> > -
override
-
exportSpan(
Span span) → Future< ResultDart< void, Exception> > -
override
-
exportTrace(
Trace trace) → Future< ResultDart< void, Exception> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited