TelemetryBatch class
Represents a batch of telemetry data to be exported.
Constructors
-
TelemetryBatch({required List<
Trace> traces, required List<Span> spans, required List<Metric> metrics, required List<TelemetryEvent> events}) - Creates a new telemetry batch.
- TelemetryBatch.empty()
- Creates an empty telemetry batch.
Properties
-
events
→ List<
TelemetryEvent> -
Events in this batch.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Checks if this batch is empty.
no setter
-
metrics
→ List<
Metric> -
Metrics in this batch.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Gets the total number of items in this batch.
no setter
-
spans
→ List<
Span> -
Spans in this batch.
final
-
traces
→ List<
Trace> -
Traces in this batch.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited